%% Script to demo ICA and PCA and Dipole fits

% Note -- this assumes you have placed the file eegplugin_pca.m in your
% plugins folder under your EEGLab folder.  This is needed since the PCA
% decomposition is not stock EEGLab.

%% Get data and channel info

% Set paths and launch EEGLab 
addpath(genpath('C:\Program Files\MATLAB\eeglab10_2_5_5a'));  % may vary depending on your location 
eeglab;

% import data file and get channel info
[ALLEEG EEG CURRENTSET ALLCOM] = eeglab;
EEG = pop_loadcnt('PIL999_VEOG.CNT' , 'dataformat', 'int16',  'keystroke', 'on');
[ALLEEG EEG CURRENTSET] = pop_newset(ALLEEG, EEG, 0,'gui','off'); 
eeglab redraw;

% Rename CB sites that are mislabeled courtesy of Neuroscan
EEG.chanlocs(26).labels='FC5';
EEG.chanlocs(27).labels='FC6';
EEG.chanlocs(28).labels='CP5';
EEG.chanlocs(29).labels='CP6';
   
% Import Channel Location Information
EEG=pop_chanedit(EEG, 'lookup','C:\\Program Files\\MATLAB\\eeglab9_0_4_6s\\plugins\\dipfit2.2\\standard_BESA\\standard-10-5-cap385.elp');
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
EEG = eeg_checkset( EEG );
eeglab redraw

%% Epoch file
EEG = pop_epoch( EEG, {  '100'  '101'  }, [-0.25        1.25], 'newname', 'CNT file epochs', 'epochinfo', 'yes');
[ALLEEG EEG CURRENTSET] = pop_newset(ALLEEG, EEG, 1,'gui','off'); 
EEG = eeg_checkset( EEG );
EEG = pop_rmbase( EEG, [-250    0]);
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
eeglab redraw


%% Remove non-EEG channels
EEG = pop_select( EEG,'nochannel',{'VEOG' 'LVEOG' 'RVEOG' 'NASION'});
[ALLEEG EEG CURRENTSET] = pop_newset(ALLEEG, EEG, 2,'gui','off'); 
eeglab redraw

%% Make copies of this set so we can use one for PCA, one for ICA
[ALLEEG EEG CURRENTSET] = pop_copyset( ALLEEG, 3, 4); % Copies to set 3
EEG = eeg_checkset( EEG );
EEG = pop_editset(EEG, 'setname', 'PCA version'); % Rename set 3 to PCA version
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
EEG = eeg_checkset( EEG );
[ALLEEG EEG CURRENTSET] = pop_copyset( ALLEEG, 4, 5); % Copy to set 4
EEG = eeg_checkset( EEG );
EEG = pop_editset(EEG, 'setname', 'ICA version'); % Rename set 4 to ICA version
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
eeglab redraw


%% Run PCA on PCA version
[ALLEEG EEG CURRENTSET] = pop_newset(ALLEEG, EEG, 5,'retrieve',4,'study',0);  % retrieves set 3 (PCA version)
eeglab redraw
% Run the PCA, storing matrices as ICA variables for later plotting, and clear temp variable
[tmp1 EEG.icawinv] = runpca(EEG.data(:,:));EEG.icaweights = pinv(EEG.icawinv);EEG.icasphere = eye(EEG.nbchan);clear tmp1;
% store results
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
eeglab redraw

%% Plot PCA components and dipoles
% make sure data are double precision
EEG.data = double(EEG.data);

pop_topoplot(EEG,0, [1:28] ,'PCA version',[5 6] ,0,'electrodes','on');
figure; pop_envtopo(EEG, [-250      1246.0938] ,'limcontrib',[-250 1246.0938],'compsplot',[4],'title', 'Largest ERP components of PCA version','electrodes','off');
EEG = pop_dipfit_settings( EEG, 'hdmfile','C:\\Program Files\\MATLAB\\eeglab10_2_5_5a\\plugins\\dipfit2.2\\standard_BESA\\standard_BESA.mat','coordformat','Spherical','mrifile','C:\\Program Files\\MATLAB\\eeglab9_0_4_6s\\plugins\\dipfit2.2\\standard_BESA\\avg152t1.mat','chanfile','C:\\Program Files\\MATLAB\\eeglab9_0_4_6s\\plugins\\dipfit2.2\\standard_BESA\\standard-10-5-cap385.elp','coord_transform',[0 0 0 0 0 0 1 1 1] ,'chansel',[1:28] );
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
% fit dipoles for first two PCs
EEG = pop_multifit(EEG, [1 2] ,'threshold',100,'dipoles',2,'dipplot','on','plotopt',{'normlen' 'on'});
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
eeglab redraw

%% Run ICA on ICA version
[ALLEEG EEG CURRENTSET] = pop_newset(ALLEEG, EEG, 4,'retrieve',5,'study',0);  % retrieves set 4 (ICA version)
eeglab redraw
EEG = pop_runica(EEG, 'icatype','runica','dataset',1,'options',{'extended' 1}); % do the ICA (and go out to Starbucks, as this will take a while)
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
eeglab redraw

%% Plot ICA components and dipoles
pop_topoplot(EEG,0, [1:27] ,'ICA version',[5 6] ,0,'electrodes','on');
figure; pop_envtopo(EEG, [-250      1246.0938] ,'limcontrib',[-250 1246.0938],'compsplot',[4],'title', 'Largest ERP components of ICA version','electrodes','off');
EEG = pop_dipfit_settings( EEG, 'hdmfile','C:\\Program Files\\MATLAB\\eeglab10_2_5_5a\\plugins\\dipfit2.2\\standard_BESA\\standard_BESA.mat','coordformat','Spherical','mrifile','C:\\Program Files\\MATLAB\\eeglab9_0_4_6s\\plugins\\dipfit2.2\\standard_BESA\\avg152t1.mat','chanfile','C:\\Program Files\\MATLAB\\eeglab9_0_4_6s\\plugins\\dipfit2.2\\standard_BESA\\standard-10-5-cap385.elp','coord_transform',[0 0 0 0 0 0 1 1 1] ,'chansel',[1:28] );
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
EEG = pop_multifit(EEG, [1 2] ,'threshold',100,'dipoles',2,'dipplot','on','plotopt',{'normlen' 'on'});
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
eeglab redraw
